<?php
// upload.php

// 检查是否提交了表单
if ($_SERVER['REQUEST_METHOD'] == 'POST') {
    // 获取用户输入的身份证号和班级
    $idCardNumber = $_POST['idCardNumber'];
    $class = $_POST['class'];

    // 检查身份证号是否是18位纯数字，或者17位数字加大写字母X
    if (!preg_match('/^\d{17}(\d|X)$/', $idCardNumber)) {
        echo "身份证号必须是18位纯数字，或者17位数字加一个大写的X！";
        exit;
    }

    // 检查班级是否选择
    if (empty($class)) {
        echo "班级必须选择！";
        exit;
    }

    // 获取上传的文件
    $uploads = [
        'idCardPhoto' => $_FILES['idCardPhoto'],
        'idFrontPhoto' => $_FILES['idFrontPhoto'],
        'idBackPhoto' => $_FILES['idBackPhoto'],
    ];

    // 检查所有文件是否上传
    foreach ($uploads as $key => $file) {
        if ($file['error'] != 0) {
            echo "请上传所有必要的照片！";
            exit;
        }
    }

    // 创建目录（如果不存在）
    $directories = [
        'ZJZ' => $class,
        'RXM' => $class,
        'GHM' => $class
    ];
    
    foreach ($directories as $folder => $classFolder) {
        $dir = __DIR__ . "/$folder/$classFolder";
        if (!is_dir($dir)) {
            mkdir($dir, 0777, true);
        }
    }

    // 处理上传文件
    $allowedImageType = ['image/jpeg'];
    $maxFileSize = 200 * 1024; // 200KB

    foreach ($uploads as $key => $file) {
        $imageInfo = getimagesize($file['tmp_name']);
        $fileType = $imageInfo['mime'];

        // 检查文件类型
        if ($fileType != 'image/jpeg') {
            echo "文件格式必须是JPG！";
            exit;
        }

        // 如果是证件照，限制文件大小
        if ($key == 'idCardPhoto' && $file['size'] > $maxFileSize) {
            echo "证件照不能大于200KB！";
            exit;
        }

        // 确定保存的文件路径
        $extension = pathinfo($file['name'], PATHINFO_EXTENSION);
        $filename = $idCardNumber . '.' . $extension;

        // 确定保存路径
        $folderName = '';
        if ($key == 'idCardPhoto') {
            $folderName = 'ZJZ';
            $successMessage = '证件照上传成功！';
        } elseif ($key == 'idFrontPhoto') {
            $folderName = 'RXM';
            $successMessage = '身份证人像面上传成功！';
        } elseif ($key == 'idBackPhoto') {
            $folderName = 'GHM';
            $successMessage = '身份证国徽面上传成功！';
        }

        $uploadDir = __DIR__ . "/$folderName/$class";
        $uploadPath = $uploadDir . '/' . $filename;

        // 上传文件
        if (move_uploaded_file($file['tmp_name'], $uploadPath)) {
            echo $successMessage . "<br>";  // 每个成功提示后加上 <br> 标签，确保换行
        } else {
            echo "$key 上传失败！<br>";  // 上传失败时也换行显示
        }
    }
}
?>
